@@ -24,22 +24,15 @@ def median(data_list):
         * "median":http://en.wikipedia.org/wiki/Median
     
     """
-    # Check to make sure that the values provided are lists
-    if not isinstance(data_list, (list, tuple)):
-        raise TypeError('First input must be a list or tuple. You input a %s' % type(data_list))
-        
     # Convert all the values to floats and test to make sure there aren't any strings in there
     try:
         data_list = map(float, data_list)
-    except ValueError:
-        raise ValueError('Input values should be a number, your first input contains something else')
-        
+    except TypeError:
+        raise TypeError('Input values should be a number, your first input contains something else')
     # Fetch the total number of values
     n = len(data_list)
-    
     # Sort the values from top to bottom
     data_list.sort()
-    
     # Test whether the n is odd
     if n & 1:
         # If is is, get the index simply by dividing it in half
@@ -50,5 +43,4 @@ def median(data_list):
         low_index = (n / 2) - 1
         high_index = n / 2
         median = (data_list[low_index] + data_list[high_index]) / 2.0
-    
     return median
